@@ -2,7 +2,7 @@ import tensorflow as tf
 from tensorflow import keras
 from tensorflow.keras import backend as K
 from keras_cv_attention_models.download_and_load import reload_model_weights_with_mismatch
-from keras_cv_attention_models.attention_layers import batchnorm_with_activation, conv2d_no_bias, activation_by_name
+from keras_cv_attention_models.attention_layers import batchnorm_with_activation, conv2d_no_bias, activation_by_name, add_pre_post_process
 
 
 PRETRAINED_DICT = {
@@ -217,6 +217,7 @@ def LeViT(
             out = [out, distill]
 
     model = keras.models.Model(inputs, out, name=model_name)
+    add_pre_post_process(model, rescale_mode="torch")
     reload_model_weights_with_mismatch(model, PRETRAINED_DICT, "levit", MultiHeadPositionalEmbedding, input_shape=input_shape, pretrained=pretrained)
     return model
 
