@@ -1,7 +1,7 @@
 from tensorflow import keras
 from tensorflow.keras import backend as K
 from keras_cv_attention_models.download_and_load import reload_model_weights
-from keras_cv_attention_models.attention_layers import activation_by_name
+from keras_cv_attention_models.attention_layers import activation_by_name, add_pre_post_process
 
 BATCH_NORM_EPSILON = 1e-5
 
@@ -85,6 +85,7 @@ def MLPMixer(
         model = SAMModel(inputs, nn, name=model_name)
     else:
         model = keras.Model(inputs, nn, name=model_name)
+    add_pre_post_process(model, rescale_mode="tf")
     reload_model_weights(model, pretrained_dict=PRETRAINED_DICT, sub_release="mlp_family", input_shape=input_shape, pretrained=pretrained)
     return model
 
