@@ -2,7 +2,7 @@ import tensorflow as tf
 from tensorflow import keras
 from tensorflow.keras import backend as K
 from keras_cv_attention_models.download_and_load import reload_model_weights
-from keras_cv_attention_models.attention_layers import activation_by_name, drop_block, eca_module, se_module, make_divisible
+from keras_cv_attention_models.attention_layers import activation_by_name, drop_block, eca_module, se_module, make_divisible, add_pre_post_process
 
 PRETRAINED_DICT = {
     "nfnetf0": {"imagenet": "7f8ee8639d468597de41566ce1b481c7"},
@@ -263,6 +263,7 @@ def NormFreeNet(
         nn = keras.layers.Dense(num_classes, dtype="float32", activation=classifier_activation, name="predictions")(nn)
 
     model = keras.models.Model(inputs, nn, name=model_name)
+    add_pre_post_process(model, rescale_mode="torch")
     reload_model_weights(model, pretrained_dict=PRETRAINED_DICT, sub_release="nfnets", input_shape=input_shape, pretrained=pretrained)
     return model
 
